PIL Package (autodoc of remaining modules)
==========================================

Reference for modules whose documentation has not yet been ported or written
can be found here.

:mod:`PIL` Module
-----------------

.. py:module:: PIL

.. autoexception:: UnidentifiedImageError
    :show-inheritance:

:mod:`~PIL.BdfFontFile` Module
------------------------------

.. automodule:: PIL.BdfFontFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.ContainerIO` Module
------------------------------

.. automodule:: PIL.ContainerIO
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.FontFile` Module
---------------------------

.. automodule:: PIL.FontFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.GdImageFile` Module
------------------------------

.. automodule:: PIL.GdImageFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.GimpGradientFile` Module
-----------------------------------

.. automodule:: PIL.GimpGradientFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.GimpPaletteFile` Module
----------------------------------

.. automodule:: PIL.GimpPaletteFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.ImageDraw2` Module
-----------------------------

.. automodule:: PIL.ImageDraw2
    :members:
    :member-order: bysource
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.ImageTransform` Module
---------------------------------

.. automodule:: PIL.ImageTransform
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PaletteFile` Module
------------------------------

.. automodule:: PIL.PaletteFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.PcfFontFile` Module
------------------------------

.. automodule:: PIL.PcfFontFile
    :members:
    :undoc-members:
    :show-inheritance:

:class:`.PngImagePlugin.iTXt` Class
-----------------------------------

.. autoclass:: PIL.PngImagePlugin.iTXt
    :members:
    :undoc-members:
    :show-inheritance:

    .. method:: __new__(cls, text, lang, tkey)

        :param value: value for this key
        :param lang: language code
        :param tkey: UTF-8 version of the key name

:class:`.PngImagePlugin.PngInfo` Class
--------------------------------------

.. autoclass:: PIL.PngImagePlugin.PngInfo
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`~PIL.TarIO` Module
------------------------

.. automodule:: PIL.TarIO
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL.WalImageFile` Module
-------------------------------

.. automodule:: PIL.WalImageFile
    :members:
    :undoc-members:
    :show-inheritance:
